.. _api_catalog_section:

:mod:`repoze.catalog.catalog`
-----------------------------

.. automodule:: repoze.catalog.catalog

  .. autoclass:: Catalog
     :members:

.. _api_fieldindex_section:

:mod:`repoze.catalog.indexes.field`
-----------------------------------

.. automodule:: repoze.catalog.indexes.field

   .. autoclass:: CatalogFieldIndex
      :members:

.. _api_keywordindex_section:

:mod:`repoze.catalog.indexes.keyword`
-------------------------------------

.. automodule:: repoze.catalog.indexes.keyword

   .. autoclass:: CatalogKeywordIndex
      :members:

.. _api_textindex_section:

:mod:`repoze.catalog.indexes.text`
-----------------------------------

.. automodule:: repoze.catalog.indexes.text

   .. autoclass:: CatalogTextIndex
      :members:

.. _api_facetindex_section:

:mod:`repoze.catalog.indexes.facet`
-------------------------------------

.. automodule:: repoze.catalog.indexes.facet

   .. autoclass:: CatalogFacetIndex
      :members:

:mod:`repoze.catalog.indexes.path`
----------------------------------

.. automodule:: repoze.catalog.indexes.path

   .. autoclass:: CatalogPathIndex
      :members:

:mod:`repoze.catalog.indexes.path2`
-----------------------------------

.. automodule:: repoze.catalog.indexes.path2

   .. autoclass:: CatalogPathIndex2
      :members:

.. _api_document_section:

:mod:`repoze.catalog.document`
------------------------------

.. automodule:: repoze.catalog.document

  .. autoclass:: DocumentMap
     :members:

